#
# spec file for package python-pyScss
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2014 LISA GmbH, Bingen, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
Name:           python-pyScss
Version:        1.4.0
Release:        2.5
Summary:        pyScss, a Scss compiler for Python
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/Kronuz/pyScss
Source:         https://github.com/Kronuz/pyScss/archive/refs/tags/v%{version}.tar.gz#/pyScss-%{version}.tar.gz
# PATCH-FIX-UPSTREAM python-311.patch gh#Kronuz/pyScss#426
Patch0:         python-311.patch
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six}
BuildRequires:  pcre-devel
BuildRequires:  python-rpm-macros
Requires:       python-setuptools
Requires:       python-six
Requires(post): update-alternatives
Requires(postun):update-alternatives
%python_subpackages

%description
pyScss is a compiler for SCSS flavor of the Sass language, a superset of CSS3
that adds programming capabilities and some other syntactic sugar.

95% of Sass 3.2 is supported.  If it's not supported, it's a bug!  Please file
a ticket.

Most of Compass 0.11 is also built in.

Documentation:
http://pyscss.readthedocs.org/en/latest/

The canonical syntax reference is part of the Ruby Sass documentation:
http://sass-lang.com/docs/yardoc/file.SASS_REFERENCE.html

%prep
%autosetup -p1 -n pyScss-%{version}

%build
export CFLAGS="%{optflags}"
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/pyscss
%python_clone -a %{buildroot}%{_bindir}/less2scss

%post
%python_install_alternative pyscss
%python_install_alternative less2scss

%postun
%python_uninstall_alternative pyscss
%python_uninstall_alternative less2scss

%check
# test_stdio depends on 'python' binary
%pytest -k 'not test_stdio'

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitearch}/scss
%{python_sitearch}/pyScss-%{version}*-info
%python_alternative %{_bindir}/pyscss
%python_alternative %{_bindir}/less2scss

%changelog
* Tue Feb 21 2023 Daniel Garcia <daniel.garcia@suse.com>
- Add python-311.patch to support python 3.11
  gh#Kronuz/pyScss#426
* Sat Oct  1 2022 Dirk Müller <dmueller@suse.com>
- update to 1.4.0:
  * Add selector-append function support
  * Fix FutureWarning
  * Fix collections deprecation warning
  * use pathlib2 instead of pathlib
- drop merged_pr_408.patch, pr_411.patch (upstream)
* Tue Jan 11 2022 John Vandenberg <jayvdb@gmail.com>
- Activate tests
- Add missing build dependency six
- Add pr_411.patch for Python 3.10 support
- Add merged_pr_408.patch for pytest 6 support
- Disable Python 2 builds due to incompatibility
* Wed Apr 29 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.3.7:
  * fix setup.py compatibility with newer setuptools
* Mon Mar 23 2020 pgajdos@suse.com
- version update to 1.3.6
  * no upstream changelog
* Wed May  2 2018 dmueller@suse.com
- convert to singlespec
* Tue Jul  5 2016 aplanas@suse.com
- update to 1.3.5
  * The new less2scss module attempts to convert Less syntax to SCSS.
  * The *-exists functions from Sass 3.3 are now supported.
  * The contents of a file @import-ed in the middle of an input file
    now appears in the expected place, not at the end of the output.
  * Double-slashes within URLs, as often happens with base64-encoded
    data URLs, are no longer stripped as comments.
  * Nesting selectors that end with a combinator, e.g. div > { p {
    ... } }, now works correctly.
  * invert() is now left alone when the argument is a number,
    indicating the CSS filter rather than the Sass function.
  * if() now evaluates its arguments lazily.
  * str-slice() now silently corrects out-of-bounds indices.
  * append() now defaults to returning a space-delimited list, when
    the given list has fewer than two elements.
  * -moz-calc and -webkit-calc are recognized as variants of the
    calc() CSS function.
  * Filenames containing dots can now be imported.
  * Properties with a computed value of null are now omitted from the
    output.
  * The opacity token in IE's strange alpha(opacity=N) construct is
    now recognized case-insensitively.
  * The Compass gradient functions now recognize currentColor as a
    color.
  * The fonts extension should now work under Python 3.
  * Escaped astral plane characters no longer crash narrow Python 2
    builds.
  * The alpha value in rgba(...) is no longer truncated to only two
    decimal places.
  * Some edge cases with float precision were fixed, so 742px - 40px
    is no longer 701.99999999px.
* Fri May  8 2015 dmueller@suse.com
- add missing dependency on python-enum34
* Mon May  4 2015 dmueller@suse.com
- update to 1.3.4:
  * no changelog available
* Fri Oct 10 2014 dmueller@suse.com
- install README/LICENSE
* Mon Oct  6 2014 p.drouand@gmail.com
- Add python-six requirement; new dependency
* Sat Sep 27 2014 dmueller@suse.com
- update to 1.2.1:
  * Bootstrap 3.2 compatibility fixes
* Fri Sep 12 2014 dmueller@suse.com
- update to 1.2.0post3:
  * This is a significant release that greatly increases
  compatibility with the reference compiler; in particular,
  the Sass port of Bootstrap now compiles.
  * There are a lot of changes here, so please feel free to
  report any bugs you see! The goal is 100%% compatibility
  with the Ruby project.
  * Python 3 support. As a result, Python 2.5 no longer works;
  whether this is a bug or a feature is not yet clear.
  * It's possible to write custom Sass functions in Python,
  though the API for this is not final.
  * Experimental support for the map type and destructuring
  @each, both unreleased additions to the Ruby project.
  * Support for the new string and list functions in Sass 3.3.
  * Added background-brushed.
  Backwards-incompatible changes
  * Configuration via monkeypatching the scss module no
  longer works. Monkeypatch scss.config instead.
  * em and px are no longer compatible.
  * Unrecognized variable names are now a fatal error.
* Mon May 26 2014 hpj@urpla.net
- version 1.1.5: initial build
